@@ -16,39 +16,38 @@ eet_dictionary_add(void)
 {
    Eet_Dictionary *new;
 
-   new = calloc(1, sizeof (Eet_Dictionary));
+   new = eet_dictionary_calloc(1);
    if (!new)
-      return NULL;
+     return NULL;
 
    memset(new->hash, -1, sizeof (int) * 256);
 
    return new;
-} /* eet_dictionary_add */
+}
 
 void
 eet_dictionary_free(Eet_Dictionary *ed)
 {
-   if (ed)
-     {
-        int i;
+   int i;
 
-        for (i = 0; i < ed->count; ++i)
-          if (ed->all[i].allocated)
-            eina_stringshare_del(ed->all[i].str);
+   if (!ed) return;
 
-        if (ed->all)
-          free(ed->all);
+   for (i = 0; i < ed->count; ++i)
+     if (ed->all[i].allocated)
+       eina_stringshare_del(ed->all[i].str);
 
-        if (ed->converts) eina_hash_free(ed->converts);
+   if (ed->all)
+     free(ed->all);
 
-        free(ed);
-     }
-} /* eet_dictionary_free */
+   if (ed->converts) eina_hash_free(ed->converts);
+
+   eet_dictionary_mp_free(ed);
+}
 
 static int
 _eet_dictionary_lookup(Eet_Dictionary *ed,
                        const char     *string,
-		       int             len,
+                       int             len,
                        int             hash)
 {
    Eina_Bool found = EINA_FALSE;
@@ -59,25 +58,25 @@ _eet_dictionary_lookup(Eet_Dictionary *ed,
 
    while (current != -1)
      {
-	if (ed->all[current].len == len)
-	  {
+        if (ed->all[current].len == len)
+          {
              if (ed->all[current].str &&
                  (ed->all[current].str == string || strcmp(ed->all[current].str, string) == 0))
                {
                   found = EINA_TRUE;
                   break;
                }
-	  }
+          }
 
         prev = current;
         current = ed->all[current].next;
      }
 
    if (current == -1 && found)
-      return prev;
+     return prev;
 
    return current;
-} /* _eet_dictionary_lookup */
+}
 
 int
 eet_dictionary_string_add(Eet_Dictionary *ed,
@@ -90,7 +89,7 @@ eet_dictionary_string_add(Eet_Dictionary *ed,
    int len;
 
    if (!ed)
-      return -1;
+     return -1;
 
    hash = _eet_hash_gen(string, 8);
    len = strlen(string) + 1;
@@ -99,7 +98,7 @@ eet_dictionary_string_add(Eet_Dictionary *ed,
 
    if (idx != -1)
      {
-        if (ed->all[idx].str && (ed->all[idx].str == string ||  strcmp(ed->all[idx].str, string) == 0))
+        if (ed->all[idx].str && (ed->all[idx].str == string || strcmp(ed->all[idx].str, string) == 0))
           return idx;
      }
 
@@ -110,9 +109,9 @@ eet_dictionary_string_add(Eet_Dictionary *ed,
 
         total = ed->total + 8;
 
-        new = realloc(ed->all, sizeof (Eet_String) * total);
+        new = realloc(ed->all, total * sizeof(Eet_String));
         if (!new)
-           return -1;
+          return -1;
 
         ed->all = new;
         ed->total = total;
@@ -120,7 +119,7 @@ eet_dictionary_string_add(Eet_Dictionary *ed,
 
    str = eina_stringshare_add(string);
    if (!str)
-      return -1;
+     return -1;
 
    current = ed->all + ed->count;
 
@@ -143,58 +142,64 @@ eet_dictionary_string_add(Eet_Dictionary *ed,
         current->prev = ed->all[idx].prev;
 
         if (current->next != -1)
-           ed->all[current->next].prev = ed->count;
+          ed->all[current->next].prev = ed->count;
 
         if (current->prev != -1)
-           ed->all[current->prev].next = ed->count;
+          ed->all[current->prev].next = ed->count;
         else
-           ed->hash[hash] = ed->count;
+          ed->hash[hash] = ed->count;
      }
 
    return ed->count++;
-} /* eet_dictionary_string_add */
+}
 
 int
 eet_dictionary_string_get_size(const Eet_Dictionary *ed,
                                int                   idx)
 {
    if (!ed)
-      return 0;
+     return 0;
 
    if (idx < 0)
-      return 0;
+     return 0;
 
    if (idx < ed->count)
-      return ed->all[idx].len;
+     return ed->all[idx].len;
 
    return 0;
-} /* eet_dictionary_string_get_size */
+}
+
+EAPI int
+eet_dictionary_count(const Eet_Dictionary *ed)
+{
+  return ed->count;
+}
 
 int
 eet_dictionary_string_get_hash(const Eet_Dictionary *ed,
                                int                   idx)
 {
    if (!ed)
-      return -1;
+     return -1;
 
    if (idx < 0)
-      return -1;
+     return -1;
 
    if (idx < ed->count)
-      return ed->all[idx].hash;
+     return ed->all[idx].hash;
 
    return -1;
-} /* eet_dictionary_string_get_hash */
+}
 
 const char *
 eet_dictionary_string_get_char(const Eet_Dictionary *ed,
                                int                   idx)
 {
    if (!ed)
-      return NULL;
+     return NULL;
 
    if (idx < 0)
-      return NULL;
+     return NULL;
 
    if (idx < ed->count)
      {
@@ -202,7 +207,7 @@ eet_dictionary_string_get_char(const Eet_Dictionary *ed,
         /* Windows file system could change the mmaped file when replacing a file. So we need to copy all string in memory to avoid bugs. */
         if (!ed->all[idx].allocated)
           {
-             ed->all[idx].str = strdup(ed->all[idx].str);
+             ed->all[idx].str = eina_stringshare_add(ed->all[idx].str);
              ed->all[idx].allocated = EINA_TRUE;
           }
 #endif /* ifdef _WIN32 */
@@ -210,7 +215,7 @@ eet_dictionary_string_get_char(const Eet_Dictionary *ed,
      }
 
    return NULL;
-} /* eet_dictionary_string_get_char */
+}
 
 static inline Eina_Bool
 _eet_dictionary_string_get_me_cache(const char *s,
@@ -227,7 +232,7 @@ _eet_dictionary_string_get_me_cache(const char *s,
      }
 
    return EINA_FALSE;
-} /* _eet_dictionary_string_get_me_cache */
+}
 
 static inline Eina_Bool
 _eet_dictionary_string_get_float_cache(const char *s,
@@ -240,15 +245,15 @@ _eet_dictionary_string_get_float_cache(const char *s,
    if (_eet_dictionary_string_get_me_cache(s, len, &mantisse, &exponent))
      {
         if (s[4] == '+')
-           *result = (float)(mantisse << exponent);
+          *result = (float)(mantisse << exponent);
         else
-           *result = (float)mantisse / (float)(1 << exponent);
+          *result = (float)mantisse / (float)(1 << exponent);
 
         return EINA_TRUE;
      }
 
    return EINA_FALSE;
-} /* _eet_dictionary_string_get_float_cache */
+}
 
 static inline Eina_Bool
 _eet_dictionary_string_get_double_cache(const char *s,
@@ -261,15 +266,15 @@ _eet_dictionary_string_get_double_cache(const char *s,
    if (_eet_dictionary_string_get_me_cache(s, len, &mantisse, &exponent))
      {
         if (s[4] == '+')
-           *result = (double)(mantisse << exponent);
+          *result = (double)(mantisse << exponent);
         else
-           *result = (double)mantisse / (float)(1 << exponent);
+          *result = (double)mantisse / (float)(1 << exponent);
 
         return EINA_TRUE;
      }
 
    return EINA_FALSE;
-} /* _eet_dictionary_string_get_double_cache */
+}
 
 static inline Eina_Bool
 _eet_dictionary_test(const Eet_Dictionary *ed,
@@ -277,24 +282,24 @@ _eet_dictionary_test(const Eet_Dictionary *ed,
                      void                 *result)
 {
    if (!result)
-      return EINA_FALSE;
+     return EINA_FALSE;
 
    if (!ed)
-      return EINA_FALSE;
+     return EINA_FALSE;
 
    if (idx < 0)
-      return EINA_FALSE;
+     return EINA_FALSE;
 
    if (!(idx < ed->count))
-      return EINA_FALSE;
+     return EINA_FALSE;
 
    return EINA_TRUE;
-} /* _eet_dictionary_test */
+}
 
 static Eet_Convert *
 eet_dictionary_convert_get(const Eet_Dictionary *ed,
-                           int idx,
-                           const char **str)
+                           int                   idx,
+                           const char          **str)
 {
    Eet_Convert *result;
 
@@ -302,7 +307,7 @@ eet_dictionary_convert_get(const Eet_Dictionary *ed,
 
    if (!ed->converts)
      {
-        ((Eet_Dictionary*)ed)->converts = eina_hash_int32_new(free);
+        ((Eet_Dictionary *)ed)->converts = eina_hash_int32_new(free);
 
         goto add_convert;
      }
@@ -310,7 +315,7 @@ eet_dictionary_convert_get(const Eet_Dictionary *ed,
    result = eina_hash_find(ed->converts, &idx);
    if (result) return result;
 
- add_convert:
+add_convert:
    result = calloc(1, sizeof (Eet_Convert));
 
    eina_hash_add(ed->converts, &idx, result);
@@ -326,7 +331,7 @@ eet_dictionary_string_get_float(const Eet_Dictionary *ed,
    const char *str;
 
    if (!_eet_dictionary_test(ed, idx, result))
-      return EINA_FALSE;
+     return EINA_FALSE;
 
    convert = eet_dictionary_convert_get(ed, idx, &str);
    if (!convert) return EINA_FALSE;
@@ -341,7 +346,7 @@ eet_dictionary_string_get_float(const Eet_Dictionary *ed,
 
              if (eina_convert_atod(str, ed->all[idx].len, &mantisse,
                                    &exponent) == EINA_FALSE)
-                return EINA_FALSE;
+               return EINA_FALSE;
 
              convert->f = ldexpf((float)mantisse, exponent);
           }
@@ -351,7 +356,7 @@ eet_dictionary_string_get_float(const Eet_Dictionary *ed,
 
    *result = convert->f;
    return EINA_TRUE;
-} /* eet_dictionary_string_get_float */
+}
 
 Eina_Bool
 eet_dictionary_string_get_double(const Eet_Dictionary *ed,
@@ -362,7 +367,7 @@ eet_dictionary_string_get_double(const Eet_Dictionary *ed,
    const char *str;
 
    if (!_eet_dictionary_test(ed, idx, result))
-      return EINA_FALSE;
+     return EINA_FALSE;
 
    convert = eet_dictionary_convert_get(ed, idx, &str);
    if (!convert) return EINA_FALSE;
@@ -377,7 +382,7 @@ eet_dictionary_string_get_double(const Eet_Dictionary *ed,
 
              if (eina_convert_atod(str, ed->all[idx].len, &mantisse,
                                    &exponent) == EINA_FALSE)
-                return EINA_FALSE;
+               return EINA_FALSE;
 
              convert->d = ldexp((double)mantisse, exponent);
           }
@@ -387,7 +392,7 @@ eet_dictionary_string_get_double(const Eet_Dictionary *ed,
 
    *result = convert->d;
    return EINA_TRUE;
-} /* eet_dictionary_string_get_double */
+}
 
 Eina_Bool
 eet_dictionary_string_get_fp(const Eet_Dictionary *ed,
@@ -398,7 +403,7 @@ eet_dictionary_string_get_fp(const Eet_Dictionary *ed,
    const char *str;
 
    if (!_eet_dictionary_test(ed, idx, result))
-      return EINA_FALSE;
+     return EINA_FALSE;
 
    convert = eet_dictionary_convert_get(ed, idx, &str);
    if (!convert) return EINA_FALSE;
@@ -408,7 +413,7 @@ eet_dictionary_string_get_fp(const Eet_Dictionary *ed,
         Eina_F32p32 fp;
 
         if (!eina_convert_atofp(str, ed->all[idx].len, &fp))
-           return EINA_FALSE;
+          return EINA_FALSE;
 
         convert->fp = fp;
         convert->type |= EET_D_FIXED_POINT;
@@ -416,7 +421,7 @@ eet_dictionary_string_get_fp(const Eet_Dictionary *ed,
 
    *result = convert->fp;
    return EINA_TRUE;
-} /* eet_dictionary_string_get_fp */
+}
 
 EAPI int
 eet_dictionary_string_check(Eet_Dictionary *ed,
@@ -425,15 +430,15 @@ eet_dictionary_string_check(Eet_Dictionary *ed,
    int i;
 
    if ((!ed) || (!string))
-      return 0;
+     return 0;
 
    if ((ed->start <= string) && (string < ed->end))
-      return 1;
+     return 1;
 
    for (i = 0; i < ed->count; ++i)
      if ((ed->all[i].allocated) && ed->all[i].str == string)
        return 1;
 
    return 0;
-} /* eet_dictionary_string_check */
+}
 
